<!-- resources/views/home.blade.php -->

@extends('layout.app')

@section('title', 'Account Details')

@section('content')
<section class="container pt-5">
    <div class="row">

        <!-- Sidebar (User info + Account menu) -->
        @include('Include.aside_account')

        <!-- Account details -->
        <div class="col-md-8 offset-lg-1 pb-5 mb-2 mb-lg-4 pt-md-5 mt-n3 mt-md-0">
            <div class="ps-md-3 ps-lg-0 mt-md-2 py-md-4">
                <h1 class="h2 pt-xl-1 pb-3">Account Details</h1>
                @if ($errors->any())
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
                @endif
                @if (session('success'))
                <div class="alert alert-success">
                    {{ session('success') }}
                </div>
                @endif
                @if (session('error'))
                <div class="alert alert-danger">
                    {{ session('error') }}
                </div>
                @endif
                <!-- Basic info -->
                <h2 class="h5 text-primary mb-4">Basic Information</h2>
                @php
                    $user = \App\Models\User::where('id', Auth::user()->id)->first();
                    if($user->isTeacher()){
                        $teacher = \App\Models\Teacher::where('user_id', Auth::user()->id)->first();
                    }
                    if($user->isStudent()){
                        $student = \App\Models\Student::where('user_id', Auth::user()->id)->first();
                    }
                @endphp

                <form class="needs-validation border-bottom pb-3 pb-lg-4" method="POST" action="{{ route('auth.update', $user->id) }}" novalidate>
                    @csrf
                    @method('PUT') <!-- or PATCH based on your routing -->

                    <div class="row pb-2">
                        <div class="col-sm-6 mb-4">
                            <label for="fn" class="form-label fs-base">Full Name</label>
                            <input type="text" id="fn" name="name" class="form-control form-control-lg" value="{{ old('name', $user->name) }}" required>
                            <div class="invalid-feedback">Please enter your full name!</div>
                        </div>

                        <div class="col-sm-6 mb-4">
                            <label for="email" class="form-label fs-base">Email Address</label>
                            <input type="email" id="email" name="email" class="form-control form-control-lg" value="{{ old('email', $user->email) }}" required>
                            <div class="invalid-feedback">Please provide a valid email address!</div>
                        </div>

                        {{-- <div class="col-sm-6 mb-4">
                            <label for="phone" class="form-label fs-base">Phone</label>
                            <input type="text" id="phone" name="phone" class="form-control form-control-lg" value="{{ old('phone', $user->phone) }}" placeholder="+ ___ ___ __" data-format='{"numericOnly": true, "delimiters": ["+1 ", " ", " "], "blocks": [0, 3, 3, 2]}'>
                        </div> --}}

                        <!-- Display student-specific data if the user is a student -->
                        @if($user->isStudent())
                            <div class="col-sm-6 mb-4">
                                <label for="age" class="form-label fs-base">Age</label>
                                <input type="number" id="age" name="age" class="form-control form-control-lg" value="{{ old('age', $student->age ?? '') }}">
                            </div>
                            <div class="col-sm-6 mb-4">
                                <label for="grade_level" class="form-label fs-base">Grade Level</label>
                                <input type="text" id="grade_level" name="grade_level" class="form-control form-control-lg" value="{{ old('grade_level', $student->grade_level ?? '') }}">
                            </div>
                            <div class="col-sm-6 mb-4">
                                <label for="system" class="form-label fs-base">System</label>
                                <input type="text" id="system" name="system" class="form-control form-control-lg" value="{{ old('system', $student->system ?? '') }}">
                            </div>
                        @endif

                        <!-- Display teacher-specific data if the user is a teacher -->
                        @if($user->isTeacher())
                            <div class="col-sm-6 mb-4">
                                <label for="subject" class="form-label fs-base">Subject</label>
                                <input type="text" id="subject" name="subject" class="form-control form-control-lg" value="{{ old('subject', $teacher->subject ?? '') }}">
                            </div>
                            <div class="col-sm-6 mb-4">
                                <label for="price_per_session" class="form-label fs-base">Price per Session</label>
                                <input type="number" id="price_per_session" name="price_per_session" class="form-control form-control-lg" value="{{ old('price_per_session', $teacher->price_per_session ?? '') }}">
                            </div>
                            <div class="col-sm-6 mb-4">
                                <label for="profile_photo" class="form-label fs-base">Profile Photo</label>
                                <input type="file" id="profile_photo" name="profile_photo" class="form-control form-control-lg">
                            </div>
                        @endif
                    </div>

                    <div class="d-flex mb-3">
                        <button type="submit" class="btn btn-primary">Save Changes</button>
                    </div>
                </form>

                {{-- <h2 class="h5 text-primary pt-1 pt-lg-3 mt-4">Forget Password</h2> --}}

                <div class="form-check mb-4">
                </div>
                {{-- <a href="{{ route('forget.password.form') }}" class="btn btn-danger">
                    Change Password
                </a> --}}
            </div>
        </div>
    </div>
</section>
@endsection
