<!-- resources/views/courses.blade.php -->

@extends('layout.app')

@section('title', 'Courses Management')

@section('content')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.5/dist/bootstrap-table.min.css">

<section class="container pt-5">
    <div class="row">

      <!-- Sidebar (User info + Account menu) -->
      @include('admin.Include.aside_account')

      <!-- Account details -->
      <div class="col-md-8 offset-lg-1 pb-5 mb-2 mb-lg-4 pt-md-5 mt-n3 mt-md-0">
        <div class="notification" id="notification">
          @if (session('success'))
              <div class="alert alert-success fade show" role="alert">
                  {{ session('success') }}
                  <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
              </div>
          @endif
      
          @if ($errors->any())
          <div class="alert alert-success fade show" role="alert">
              <ul>
                      @foreach ($errors->all() as $error)
                          <li>{{ $error }}</li>
                      @endforeach
                  </ul>
              </div>
          @endif
        </div>

        <script>
          document.addEventListener("DOMContentLoaded", function() {
              const notification = document.getElementById('notification');
              if (notification) {
                  setTimeout(() => {
                      notification.style.display = 'none';
                  }, 5000);
              }
          });
        </script>

        <div class="d-grid gap-2 d-md-flex justify-content-md-end">
          <button class="btn btn-primary" type="button" data-bs-toggle="modal" data-bs-target="#addCourseModal">
              <i class='bx bxs-plus-circle'></i> Add New Course
          </button>
        </div>

        <!-- Add Course Modal -->
        <div class="modal fade" id="addCourseModal" tabindex="-1" role="dialog" aria-labelledby="addCourseLabel" aria-hidden="true">
          <div class="modal-dialog" role="document">
              <div class="modal-content">
                  <div class="modal-header">
                      <h5 class="modal-title" id="addCourseLabel">Add Course</h5>
                      <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                  </div>

                  <form method="POST" action="{{ route('course.add') }}" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="course_name" class="form-label">Course Name</label>
                            <input type="text" id="course_name" name="name" class="form-control" required>
                        </div>
                
                        
                        <div class="mb-3">
                            <label for="course_description" class="form-label">Course Description</label>
                            <textarea id="course_description" name="description" class="form-control" required></textarea>
                        </div>
                
                        <!-- حقل تحديد النظام -->
                        <div class="mb-3">
                            <label for="course_system" class="form-label">Course System</label>
                            <select id="course_system" name="system" class="form-select" required>
                                <option value="American">American</option>
                                <option value="British">British</option>
                                <option value="Masry">Masry</option>
                            </select>
                        </div>
                        <div class="form-group mb-3">
                            <label for="course_img">Course Image</label>
                            <input type="file" name="course_img" class="form-control" onchange="previewImage(event)">
                        </div>
                        <img id="courseImage" src="" alt="image Preview" style="display: none; max-width: 50%; margin-top: 10px;" class="mb-3">

                        <script>
                            function previewImage(event) {
                                const courseImage = document.getElementById('courseImage');
                                const file = event.target.files[0];
                                if (file) {
                                    const reader = new FileReader();
                                    reader.onload = function(e) {
                                        courseImage.src = e.target.result;
                                        courseImage.style.display = 'block';
                                    }
                                    reader.readAsDataURL(file);
                                } else {
                                    courseImage.src = '';
                                    courseImage.style.display = 'none';
                                }
                            }
                        </script>
                
                        <!-- حقل اختيار المدرسين -->
                        <div class="mb-3">
                            <label for="teacher_ids" class="form-label">Select Teachers</label>
                            <div>
                                @foreach($teachers as $teacher)
                                    <div class="form-check">
                                        <input class="form-check-input" type="checkbox" name="teacher_ids[]" value="{{ $teacher->id }}" id="teacher_{{ $teacher->id }}">
                                        <label class="form-check-label" for="teacher_{{ $teacher->id }}">
                                            {{ $teacher->name }}
                                        </label>
                                    </div>
                                @endforeach
                            </div>
                        </div>
                        
                    </div>
                
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Add Course</button>
                    </div>
                </form>
                
                
              </div>
          </div>
        </div>

        <div class="ps-md-3 ps-lg-0 mt-md-2 py-md-4">
            <div class="table-responsive">
              <table id="table"
                data-toggle="table"
                data-show-export="true"
                data-export-types='["csv"]' 
                data-filter-control="true"
                data-pagination="true"
                data-toolbar=".toolbar"
                data-show-footer="true"
                data-show-print="true"
                data-id-table="advancedTable"
                data-show-toggle="true"
                data-show-columns="true">
                <thead>
                    <tr>
                        <th data-field="id" data-filter-control="input">ID</th>
                        <th data-field="course_name" data-filter-control="input">Course Name</th>
                        <th data-field="system" data-filter-control="input">System</th>
 
                        <th data-field="action">Action</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($courses as $course)
                        <tr>
                            <td>{{ $course->id }}</td>
                            <td>{{ $course->name }}</td>
                            <td>{{ $course->system }}</td>
                            <td>
                                <button class="btn btn-sm btn-primary" data-bs-toggle="modal" data-bs-target="#updateCourseModal" onclick="fillUpdateModal({{ json_encode($course) }})">
                                    <i class='bx bx-edit-alt'></i>
                                </button>
                                <form action="{{ route('course.delete', $course->id) }}" method="POST" style="display:inline;">
                                    @csrf
                                    @method('DELETE')
                                    <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this course?');">
                                        <i class='bx bx-trash'></i>
                                    </button>
                                </form>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
              </table>
            </div>              
        </div>
      </div>
    </div>
  </section>

<!-- Update Course Modal -->
<div class="modal fade" id="updateCourseModal" tabindex="-1" role="dialog" aria-labelledby="updateCourseLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="updateCourseLabel">Update Course</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>

            <form method="POST" action="" id="updateCourseForm" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="course_name_update" class="form-label">Course Name</label>
                        <input type="text" id="course_name_update" name="name" class="form-control" required>
                    </div>

                    <div class="mb-3">
                        <label for="course_description_update" class="form-label">Course Description</label>
                        <textarea id="course_description_update" name="description" class="form-control" required></textarea>
                    </div>

                    <!-- حقل تحديد النظام -->
                    <div class="mb-3">
                        <label for="course_system_update" class="form-label">Course System</label>
                        <select id="course_system_update" name="system" class="form-select" required>
                            <option value="American">American</option>
                            <option value="British">British</option>
                            <option value="Masry">Masry</option>
                        </select>
                    </div>
                    <div class="form-group mb-3">
                        <label for="course_img">Course Image</label>
                        <input type="file" name="course_img" class="form-control" onchange="previewImageUpdate(event)">
                    </div>
                    <img id="courseImageUpdate" src="" alt="image Preview" style="display: none; max-width: 50%; margin-top: 10px;" class="mb-3">                        
                        <script>
                            function previewImageUpdate(event) {
                                const courseImageUpdate = document.getElementById('courseImageUpdate');
                                const file = event.target.files[0];
                                if (file) {
                                    const reader = new FileReader();
                                    reader.onload = function(e) {
                                        courseImageUpdate.src = e.target.result;
                                        courseImageUpdate.style.display = 'block';
                                    }
                                    reader.readAsDataURL(file);
                                } else {
                                    courseImageUpdate.src = '';
                                    courseImageUpdate.style.display = 'none';
                                }
                            }
                        </script>

                    <!-- حقل اختيار المدرسين -->
                    <div class="mb-3">
                        <label for="teacher_ids_update" class="form-label">Select Teachers</label>
                        <div>
                            @foreach($teachers as $teacher)
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" id="teacher_update_{{ $teacher->id }}" name="teacher_ids[]" value="{{ $teacher->id }}" 
                                     @if(in_array($teacher->id, $course->teachers->pluck('id')->toArray())) checked @endif>
                                    <label class="form-check-label" for="teacher_update_{{ $teacher->id }}">{{ $teacher->name }}</label>
                                </div>
                            @endforeach
                        </div>
                    </div>
                    
                    
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Update Course</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    function fillUpdateModal(course) {
        document.getElementById('course_name_update').value = course.name;
        document.getElementById('course_description_update').value = course.description;
        document.getElementById('course_system_update').value = course.system;

        const teacherCheckboxes = document.querySelectorAll('[id^="teacher_update_"]');
        teacherCheckboxes.forEach(checkbox => {
            checkbox.checked = course.teachers.some(teacher => teacher.id === parseInt(checkbox.value));
        });

        const courseImageUpdate = document.getElementById('courseImageUpdate');
        courseImageUpdate.src = course.course_img ? '{{ asset('storage') }}' + '/' + course.course_img : '';
        courseImageUpdate.style.display = course.course_img ? 'block' : 'none';

        const updateForm = document.getElementById('updateCourseForm');
        updateForm.action = `/courses/update/${course.id}`;
    }


</script>


@endsection
<script src="https://cdn.jsdelivr.net/npm/jquery/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/bootstrap-table.min.js"></script>

