<!-- resources/views/home.blade.php -->

@extends('layout.app')

@section('title', 'Student Management')

@section('content')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.5/dist/bootstrap-table.min.css">

<section class="container pt-5">
    <div class="row">


      <!-- Sidebar (User info + Account menu) -->
      @include('admin.Include.aside_account')


      <!-- Account details -->
      <div class="col-md-8 offset-lg-1 pb-5 mb-2 mb-lg-4 pt-md-5 mt-n3 mt-md-0">
        <div class="notification" id="notification">
          @if (session('success'))
              <div class="alert alert-success fade show" role="alert">
                  {{ session('success') }}
                  <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
              </div>
          @endif
      
          @if ($errors->any())
          <div class="alert alert-success fade show" role="alert">
              <ul>
                      @foreach ($errors->all() as $error)
                          <li>{{ $error }}</li>
                      @endforeach
                  </ul>
              </div>
          @endif

      </div>

      <script>
          document.addEventListener("DOMContentLoaded", function() {
              const notification = document.getElementById('notification');
              if (notification) {
                  setTimeout(() => {
                      notification.style.display = 'none';
                  }, 5000);
              }
          });
      </script>

      <div class="d-grid gap-2 d-md-flex justify-content-md-end">
          <button class="btn btn-primary" type="button" data-bs-toggle="modal" data-bs-target="#addTeacherModal">
              <i class='bx bxs-plus-circle'></i> Add New Student
          </button>
      </div>

      <!-- Add Teacher Modal -->
      <div class="modal fade" id="addTeacherModal" tabindex="-1" role="dialog" aria-labelledby="addTeacherLabel" aria-hidden="true">
          <div class="modal-dialog" role="document">
              <div class="modal-content">
                  <div class="modal-header">
                      <h5 class="modal-title" id="addTeacherLabel">Add Student</h5>
                      <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                  </div>

                  <form method="POST" action="{{ route('students.add') }}" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="name" class="form-label">Student Name</label>
                            <input type="text" id="name" name="name" class="form-control" required>
                        </div>
                
                        <div class="mb-3">
                            <label for="email" class="form-label">Email</label>
                            <input type="email" id="email" name="email" class="form-control" required>
                        </div>
                
                        <div class="col-12 mb-4">
                          <label for="password" class="form-label fs-base">Password</label>
                          <div class="password-toggle">
                              <input type="password" name="password" id="password" class="form-control form-control-lg" required>
                              <label class="password-toggle-btn" aria-label="Show/hide password">
                                  <input class="password-toggle-check" type="checkbox">
                                  <span class="password-toggle-indicator"></span>
                              </label>
                              <div class="invalid-feedback position-absolute start-0 top-100">Please enter a password!</div>
                          </div>
                      </div>
                      <div class="col-12 mb-4">
                          <label for="password-confirm" class="form-label fs-base">Confirm Password</label>
                          <div class="password-toggle">
                              <input type="password" name="password_confirmation" id="password-confirm" class="form-control form-control-lg" required>
                              <label class="password-toggle-btn" aria-label="Show/hide password">
                                  <input class="password-toggle-check" type="checkbox">
                                  <span class="password-toggle-indicator"></span>
                              </label>
                              <div class="invalid-feedback position-absolute start-0 top-100">Please confirm your password!</div>
                          </div>
                      </div>
                
                        <div class="mb-3">
                            <label for="age" class="form-label">Age</label>
                            <input type="number" id="age" name="age" class="form-control" required>
                        </div>
                
                        <div class="mb-3">
                            <label for="grade" class="form-label">Grade</label>
                            <input type="text" id="grade" name="grade_level" class="form-control" required>
                        </div>
                
                        <div class="mb-3">
                            <label for="system" class="form-label">System</label>
                            <input type="text" id="system" name="system" class="form-control" required>
                        </div>
                
                        <div class="mb-3">
                            <label for="profile_photo" class="form-label">Profile Photo</label>
                            <input type="file" id="profile_photo" name="profile_photo" class="form-control">
                        </div>
                    </div>
                
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Add Student</button>
                    </div>
                </form>
                
              </div>
          </div>
      </div>
        <div class="ps-md-3 ps-lg-0 mt-md-2 py-md-4">
            <div class="table-responsive">
              <table id="table"
                data-toggle="table"
                id="table"
                data-show-export="true"
                data-export-types='["csv"]' 
                data-filter-control="true"
                data-pagination="true"
                data-toolbar=".toolbar"
                data-show-footer="true"
                data-show-print="true"
                data-id-table="advancedTable"
                data-show-toggle="true"
                data-show-columns="true">
              <thead>
                    <tr>
                        <th data-field="id" data-filter-control="input">ID</th>
                        <th data-field="name" data-filter-control="input">Name</th>
                        <th data-field="email" data-filter-control="input">Email</th>
                        <th data-field="grade" data-filter-control="input">Grade</th>
                        <th data-field="age" data-filter-control="input">Age</th>
                        <th data-field="system" data-filter-control="input">System</th>
                        <th data-field="action" >Action</th>



                    </tr>
                </thead>
                <tbody>
                    @foreach($students as $student)
                        <tr>
                        <td>{{ $student->id }}</td>
                        <td>{{ $student->name}}</td>
                        <td>{{ $student->user->email}}</td>
                        <td>{{ $student->grade_level}}</td>
                        <td>{{ $student->age}}</td>
                        <td>{{ $student->system}}</td>
                        <td>
                          <button class="btn btn-sm btn-primary" data-bs-toggle="modal" data-bs-target="#exampleModal-3" onclick="fillModal({{ json_encode($student) }})">
                              <i class='bx bx-edit-alt'></i>
                            </button>
                          <form action="{{ route('students.delete', $student->id) }}" method="POST" style="display:inline;">
                              @csrf
                              @method('DELETE')
                              <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this teacher?');">
                                  <i class='bx bx-trash'></i>
                              </button>
                          </form>
                      </td>

                    </tr>
             @endforeach
            
            </tbody>
            
              </table>
              <script>
                $(function() {
                  $('#table').bootstrapTable()
                })
              </script>
              </div>              
        </div>
      </div>
    </div>
  </section>
<!-- Update Student Modal -->
<div class="modal fade" id="exampleModal-3" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
      <div class="modal-content">
          <div class="modal-header">
              <h5 class="modal-title" id="exampleModalLabel">Update Student</h5>
              <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
          </div>

          <form class="needs-validation" method="POST" action="" id="updateStudentForm" enctype="multipart/form-data" novalidate>
              @csrf
              @method('PUT') <!-- Add this line to specify PUT method for update -->
              <div class="modal-body">
                  <div class="mb-3">
                      <label for="name" class="form-label">Student Name</label>
                      <input type="text" id="name-update" name="name" class="form-control" required>
                  </div>

                  <div class="mb-3">
                      <label for="email" class="form-label">Email</label>
                      <input type="email" id="email-update" name="email" class="form-control" required>
                  </div>

                  <div class="mb-3">
                      <label for="password" class="form-label">Password</label>
                      <input type="password" id="password-update" name="password" class="form-control">
                  </div>

                  <div class="mb-3">
                      <label for="age" class="form-label">Age</label>
                      <input type="number" id="age-update" name="age" class="form-control" required>
                  </div>

                  <div class="mb-3">
                      <label for="grade" class="form-label">Grade</label>
                      <input type="text" id="grade-update" name="grade_level" class="form-control" required>
                  </div>

                  <div class="mb-3">
                      <label for="system" class="form-label">System</label>
                      <input type="text" id="system-update" name="system" class="form-control" required>
                  </div>

                  <div class="mb-3">
                      <label for="profile_photo" class="form-label">Profile Photo</label>
                      <input type="file" id="profile_photo-update" name="profile_photo" class="form-control" onchange="previewUpdateLogo(event)">
                      <img id="updateLogoPreview" src="" alt="Preview" style="display:none; max-width: 100px; margin-top: 10px;">
                  </div>
              </div>

              <script>
                  function previewUpdateLogo(event) {
                      const updateLogoPreview = document.getElementById('updateLogoPreview');
                      const file = event.target.files[0];
                      if (file) {
                          const reader = new FileReader();
                          reader.onload = function(e) {
                              updateLogoPreview.src = e.target.result;
                              updateLogoPreview.style.display = 'block';
                          }
                          reader.readAsDataURL(file);
                      } else {
                          updateLogoPreview.src = '';
                          updateLogoPreview.style.display = 'none';
                      }
                  }

                  function fillModal(student) {
                      // Populate form fields
                      console.log(student);
                      document.getElementById('name-update').value = student.name;
                      document.getElementById('email-update').value = student.user.email;
                      document.getElementById('age-update').value = student.age;
                      document.getElementById('grade-update').value = student.grade_level;
                      document.getElementById('system-update').value = student.system;
                      document.getElementById('password-update').value = ''; // Leave password empty for security
                      
                      // If profile photo exists
                      const updateLogoPreview = document.getElementById('updateLogoPreview');
                      if (student.profile_photo) {
                          updateLogoPreview.src = student.profile_photo;
                          updateLogoPreview.style.display = 'block';
                      } else {
                          updateLogoPreview.style.display = 'none';
                      }

                      // Set form action URL with student ID
                      const updateForm = document.getElementById('updateStudentForm');
                      updateForm.action = `/students/update/${student.id}`;
                  }
              </script>

              <div class="modal-footer">
                  <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                  <button type="submit" class="btn btn-primary">Update Student</button>
              </div>
          </form>
      </div>
  </div>
</div>

@endsection
<script src="https://cdn.jsdelivr.net/npm/jquery/dist/jquery.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
  
      <!-- Bootstrap Table and extensions -->
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/bootstrap-table.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/filter-control/bootstrap-table-filter-control.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/reorder-columns/bootstrap-table-reorder-columns.min.js"></script>
  
      <!-- jQuery UI and Dragtable scripts -->
      

      
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/export/bootstrap-table-export.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/print/bootstrap-table-print.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/toolbar/bootstrap-table-toolbar.min.js"></script>



<script src="https://cdn.jsdelivr.net/npm/jqueryui@1.11.1/jquery-ui.min.js"></script>
<script src="https://cdn.jsdelivr.net/gh/akottr/dragtable@master/jquery.dragtable.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/reorder-columns/bootstrap-table-reorder-columns.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/tableexport.jquery.plugin@1.29.0/tableExport.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/tableexport.jquery.plugin@1.29.0/libs/jsPDF/jspdf.umd.min.js"></script>
        <script src="{{ asset('assets/vendor/bootstrap/dist/js/bootstrap.bundle.min.js') }}"></script>