<!-- resources/views/home.blade.php -->

@extends('layout.app')

@section('title', 'Course Dashboard')

@section('content')
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.5/dist/bootstrap-table.min.css">
    <script src="https://code.jquery.com/jquery-3.4.1.slim.min.js" integrity="sha384-J6qa4849blE2+poT4WnyKhv5vZF5SrPo0iEjwBvKU7imGFAV0wwj1yYfoRSJoZ+n" crossorigin="anonymous"></script>
    <link href="https://cdn.jsdelivr.net/npm/summernote@0.9.0/dist/summernote-lite.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.9.0/dist/summernote-lite.min.js"></script>


<section class="container pt-5">
    <div class="row">

      <!-- Sidebar (User info + Account menu) -->
      @include('teacher.Include.aside_account')

      <!-- Dashboard content -->
      <div class="col-md-8 offset-lg-1 pb-5 mb-2 mb-lg-4 pt-md-5 mt-n3 mt-md-0">
        <div class="notification" id="notification">
          @if (session('success'))
              <div class="alert alert-success fade show" role="alert">
                  {{ session('success') }}
                  <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
              </div>
          @endif
          @if ($errors->any())
          <div class="alert alert-success fade show" role="alert">
              <ul>
                      @foreach ($errors->all() as $error)
                          <li>{{ $error }}</li>
                      @endforeach
                  </ul>
              </div>
          @endif
      </div>

      <script>
          document.addEventListener("DOMContentLoaded", function() {
              const notification = document.getElementById('notification');
              if (notification) {
                  setTimeout(() => {
                      notification.style.display = 'none';
                  }, 5000);
              }
          });
      </script>

      <div class="d-grid gap-2 d-md-flex justify-content-md-end">
          <button class="btn btn-primary" type="button" data-bs-toggle="modal" data-bs-target="#addLessonModal">
              <i class='bx bxs-plus-circle'></i> Add New Lesson
          </button>
      </div>

    <!-- Add Lesson Modal -->
    <div class="modal fade" id="addLessonModal" tabindex="-1" role="dialog" aria-labelledby="addLessonLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addLessonLabel">Add Lesson</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>

                <form method="POST" action="{{ route('lectures.store', $course->id) }}" enctype="multipart/form-data">
                    @csrf
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="title" class="form-label">Lecture Title</label>
                            <input type="text" id="title" name="title" class="form-control" required>
                        </div>
            
                        <div class="mb-3">
                            <label for="description" class="form-label">Description (Optional)</label>
                            <textarea id="description" name="description" class="form-control"></textarea>
                        </div>
            
                        <div class="mb-3">
                            <label for="start_time" class="form-label">Start Time</label>
                            <input type="datetime-local" id="start_time" name="start_time" class="form-control" required>
                        </div>

                        <div class="mb-3">
                            <label for="price" class="form-label">Lecture Price</label>
                            <input type="number" id="price" name="price" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label for="what_learn" class="form-label">What student 'll learn</label>
                            <textarea id="what_learn" name="what_learn" class="form-control" required></textarea>
                        </div>
                        <script>
                            $(document).ready(function() {
                                $('#what_learn').summernote({
                                    height: 300, // Height of Summernote editor
                                    placeholder: ''
                                });
                            });
                        </script>
            
                        <div class="mb-3">
                            <label for="duration" class="form-label">Duration (in minutes)</label>
                            <input type="number" id="duration" name="duration" class="form-control" required>
                        </div>

                        <!-- Upload Video Field -->
                        <div class="form-group mb-3">
                            <label for="lecture_video">Upload Lecture Video</label>
                            <input type="file" name="lecture_video" class="form-control" accept="video/mp4,video/mkv,video/avi" onchange="previewMedia(event, 'video')">
                        </div>

                        <!-- Zoom Link Field -->
                        <div class="mb-3">
                            <label for="lecture_zoom" class="form-label">Zoom Link</label>
                            <input type="url" id="lecture_zoom" name="lecture_zoom" class="form-control" placeholder="Enter Zoom link" required>
                        </div>

                        <!-- Lecture Image Field -->
                        <div class="form-group mb-3">
                            <label for="course_img">Lecture Image</label>
                            <input type="file" name="lecture_img" class="form-control" onchange="previewMedia(event, 'image')">
                        </div>
                        <div id="mediaPreview" style="display: none; max-width: 50%; margin-top: 10px;" class="mb-3">
                            <!-- Image preview -->
                            <img id="courseImage" src="" alt="image Preview" style="display: none; max-width: 100%;">
                            <!-- Video preview -->
                            <video id="courseVideo" controls style="display: none; max-width: 100%;"></video>
                        </div>

                        <script>
                            function previewMedia(event, type) {
                                const mediaPreview = document.getElementById('mediaPreview');
                                const courseImage = document.getElementById('courseImage');
                                const courseVideo = document.getElementById('courseVideo');
                                const file = event.target.files[0];

                                if (file) {
                                    const reader = new FileReader();
                                    
                                    if (type === 'image' && file.type.startsWith('image')) {
                                        reader.onload = function(e) {
                                            courseImage.src = e.target.result;
                                            courseImage.style.display = 'block';
                                            courseVideo.style.display = 'none';
                                        }
                                        reader.readAsDataURL(file);
                                        mediaPreview.style.display = 'block';
                                    } else if (type === 'video' && file.type.startsWith('video')) {
                                        const videoUrl = URL.createObjectURL(file);
                                        courseVideo.src = videoUrl;
                                        courseVideo.style.display = 'block';
                                        courseImage.style.display = 'none';
                                        mediaPreview.style.display = 'block';
                                    }
                                } else {
                                    mediaPreview.style.display = 'none';
                                }
                            }
                        </script>
                    </div>
            
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Add Lecture</button>
                    </div>
                </form>
            </div>
        </div>
    </div>


      <div class="ps-md-3 ps-lg-0 mt-md-2 py-md-4">
          <div class="table-responsive">
            <table id="table"
              data-toggle="table"
              id="table"
              data-show-export="true"
              data-export-types='["csv"]' 
              data-filter-control="true"
              data-pagination="true"
              data-toolbar=".toolbar"
              data-show-footer="true"
              data-show-print="true"
              data-id-table="advancedTable"
              data-show-toggle="true"
              data-show-columns="true">
            <thead>
                  <tr>
                      <th data-field="id" data-filter-control="input">ID</th>
                      <th data-field="lesson_name" data-filter-control="input">Lesson Name</th>
                      <th data-field="lesson_description" data-filter-control="input">Description</th>
                      <th data-field="lesson_date" data-filter-control="input">Start Time</th>
                      <th data-field="lesson_time" data-filter-control="input">Duration</th>

                      <th data-field="action">Action</th>
                  </tr>
              </thead>
              <tbody>
                  @foreach($lectures as $lesson)
                  
                      <tr>
                      <td>{{ $lesson->id }}</td>
                      <td>{{ $lesson->title }}</td>
                      <td>{{ $lesson->description }}</td>
                      <td>{{ $lesson->start_time }}</td>
                      <td>{{ $lesson->duration }}</td>

                      <td>
                        <button class="btn btn-sm btn-primary" data-bs-toggle="modal" data-bs-target="#updateLessonModal" onclick="fillModal({{ json_encode($lesson) }})">
                            <i class='bx bx-edit-alt'></i>
                        </button>
                        <form action="{{ route('lectures.destroy', ['courseId' => $course->id, 'lectureId' => $lesson->id]) }}" method="POST" style="display:inline;">
                            @csrf
                            @method('DELETE')
                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this lesson?');">
                                <i class='bx bx-trash'></i>
                            </button>
                        </form>
                        
                    </td>
                  </tr>
              @endforeach
            </tbody>
            </table>
          </div>              
      </div>
    </div>
  </section>

<!-- Update Lesson Modal -->
<div class="modal fade" id="updateLessonModal" tabindex="-1" role="dialog" aria-labelledby="updateLessonLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="updateLessonLabel">Update Lesson</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
  
            <form method="POST" action="" id="updateLessonForm" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                <div class="modal-body">
                  <input type="hidden" id="teacher_id" name="teacher_id" value="{{ Auth::user()->teacher->id }}">
  
                    <div class="mb-3">
                        <label for="lesson_name-update" class="form-label">Name</label>
                        <input type="text" id="lesson_name-update" name="title" class="form-control" required>
                    </div>
                    <div class="mb-3">
                      <label for="lesson_name-update" class="form-label">Description</label>
                      <input type="text" id="lesson_description-update" name="description" class="form-control" required>
                  </div>
                    <div class="mb-3">
                        <label for="lesson_date-update" class="form-label">Start time</label>
                        <input type="datetime-local" id="lesson_date-update" name="start_time" class="form-control" required>
                    </div>
                    <div class="mb-3">
                      <label for="price-update" class="form-label">Lecture price</label>
                      <input type="number" id="price-update" name="price" class="form-control" required>
                   </div>
                   <div class="mb-4">
                      <label for="what_learn-update" class="form-label">What student'll learn</label>  
                      <textarea id="what_learn-update" name="what_learn" class="form-control form-control-lg"></textarea>
                  </div>
                  <script>
                      $(document).ready(function() {
                          if ($.fn.summernote) {
                              $('#what_learn-update').summernote({
                                  height: 300,
                                  placeholder: 'Write what students will learn...'
                              });
                          } else {
                              console.error('Summernote لم يتم تحميله بشكل صحيح.');
                          }
                      });
                  </script>
                  
  
  
                    <div class="mb-3">
                        <label for="lesson_time-update" class="form-label">Duration</label>
                        <input type="text" id="lesson_time-update" name="duration" class="form-control" required>
                    </div>
  
                    <!-- Lecture Image -->
                    <div class="form-group mb-3">
                      <label for="course_img">Lecture Image</label>
                      <input type="file" name="lecture_img" class="form-control" onchange="previewImageUpdate(event)">
                  </div>
                  <img id="courseImageUpdate" src="" alt="image Preview" style="display: none; max-width: 50%; margin-top: 10px;" class="mb-3">
  
                  <!-- Lecture Video -->
                  <div class="form-group mb-3">
                      <label for="course_video">Lecture Video</label>
                      <input type="file" name="lecture_video" class="form-control" onchange="previewVideoUpdate(event)">
                  </div>
                  <video id="courseVideoUpdate" width="320" height="240" controls style="display: none; margin-top: 10px;" class="mb-3">
                      <source id="courseVideoSourceUpdate" src="" type="video/mp4">
                      Your browser does not support the video tag.
                  </video>     
  
                  <!-- Zoom Link -->
                  <div class="mb-3">
                      <label for="zoom_link-update" class="form-label">Zoom Link</label>
                      <input type="url" id="zoom_link-update" name="lecture_zoom" class="form-control" placeholder="Enter Zoom link" required>
                  </div>
                  
                      <script>
                          // Image Preview
                          function previewImageUpdate(event) {
                              const courseImageUpdate = document.getElementById('courseImageUpdate');
                              const file = event.target.files[0];
                              if (file) {
                                  const reader = new FileReader();
                                  reader.onload = function(e) {
                                      courseImageUpdate.src = e.target.result;
                                      courseImageUpdate.style.display = 'block';
                                  }
                                  reader.readAsDataURL(file);
                              } else {
                                  courseImageUpdate.src = '';
                                  courseImageUpdate.style.display = 'none';
                              }
                          }
  
                          // Video Preview
                          function previewVideoUpdate(event) {
                              const courseVideoUpdate = document.getElementById('courseVideoUpdate');
                              const videoSource = document.getElementById('courseVideoSourceUpdate');
                              const file = event.target.files[0];
                              if (file) {
                                  const url = URL.createObjectURL(file);
                                  videoSource.src = url;
                                  courseVideoUpdate.style.display = 'block';
                                  courseVideoUpdate.load(); // Reload the video element
                              } else {
                                  courseVideoUpdate.style.display = 'none';
                              }
                          }
                      </script>
                </div>
  
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary">Update Lesson</button>
                </div>
            </form>
        </div>
    </div>
  </div>
  
  <script>
      function fillModal(lesson) {
          const course = @json($course);
  
          document.getElementById('lesson_name-update').value = lesson.title;
          document.getElementById('lesson_description-update').value = lesson.description;
          document.getElementById('price-update').value = lesson.price;

          // Convert start_time to YYYY-MM-DD format
          const dateOnly = lesson.start_time.split(' ')[0];
          document.getElementById('lesson_date-update').value = dateOnly;
  
          document.getElementById('lesson_time-update').value = lesson.duration;
          
          // Handle image preview
          const courseImageUpdate = document.getElementById('courseImageUpdate');
          courseImageUpdate.src = lesson.lecture_img ? '{{ asset('storage') }}' + '/' + lesson.lecture_img : '';
          courseImageUpdate.style.display = lesson.lecture_img ? 'block' : 'none';
  
          // Handle video preview
          const courseVideoUpdate = document.getElementById('courseVideoUpdate');
          const videoSourceUpdate = document.getElementById('courseVideoSourceUpdate');
          if (lesson.lecture_video) {
              courseVideoUpdate.style.display = 'block';
              videoSourceUpdate.src = '{{ asset('storage') }}' + '/' + lesson.lecture_video;
              courseVideoUpdate.load(); // Reload the video element to update the source
          } else {
              courseVideoUpdate.style.display = 'none';
          }
  
          // Set the Zoom link
          document.getElementById('zoom_link-update').value = lesson.lecture_zoom;
  
          $('#what_learn-update').summernote('code', lesson.what_learn);
  
          const updateForm = document.getElementById('updateLessonForm');
          updateForm.action = `/courses/${course.id}/lectures/${lesson.id}`;
      }
  </script>
  
  

@endsection

<script src="https://cdn.jsdelivr.net/npm/jquery/dist/jquery.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
  
      <!-- Bootstrap Table and extensions -->
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/bootstrap-table.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/filter-control/bootstrap-table-filter-control.min.js"></script>
      <script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/reorder-columns/bootstrap-table-reorder-columns.min.js"></script>
  
      <!-- jQuery UI and Dragtable scripts -->
      

      
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/export/bootstrap-table-export.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/print/bootstrap-table-print.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/toolbar/bootstrap-table-toolbar.min.js"></script>



<script src="https://cdn.jsdelivr.net/npm/jqueryui@1.11.1/jquery-ui.min.js"></script>
<script src="https://cdn.jsdelivr.net/gh/akottr/dragtable@master/jquery.dragtable.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap-table@1.23.2/dist/extensions/reorder-columns/bootstrap-table-reorder-columns.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/tableexport.jquery.plugin@1.29.0/tableExport.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/tableexport.jquery.plugin@1.29.0/libs/jsPDF/jspdf.umd.min.js"></script>
<script src="{{ asset('assets/vendor/bootstrap/dist/js/bootstrap.bundle.min.js') }}"></script>
